package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.crypto.digests.SHA1Digest;
import java.math.BigInteger;
import java.util.Enumeration;

public class AuthorityKeyIdentifier extends ASN1Encodable {
   ASN1OctetString keyidentifier;
   GeneralNames certissuer;
   DERInteger certserno;

   public static AuthorityKeyIdentifier getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static AuthorityKeyIdentifier getInstance(Object obj) {
      if (obj instanceof AuthorityKeyIdentifier) {
         return (AuthorityKeyIdentifier)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new AuthorityKeyIdentifier((ASN1Sequence)obj);
      } else if (obj instanceof X509Extension) {
         return getInstance(X509Extension.convertValueToObject((X509Extension)obj));
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public AuthorityKeyIdentifier(ASN1Sequence seq) {
      this.keyidentifier = null;
      this.certissuer = null;
      this.certserno = null;
      Enumeration seq1 = seq.getObjects();

      while(seq1.hasMoreElements()) {
         ASN1TaggedObject var2;
         int var3;
         if ((var3 = (var2 = ASN1TaggedObject.getInstance(seq1.nextElement())).getTagNo()) != 0) {
            if (var3 != 1) {
               if (var3 != 2) {
                  throw new IllegalArgumentException("illegal tag");
               }

               this.certserno = DERInteger.getInstance(var2, false);
            } else {
               this.certissuer = GeneralNames.getInstance(var2, false);
            }
         } else {
            this.keyidentifier = ASN1OctetString.getInstance(var2, false);
         }
      }

   }

   public AuthorityKeyIdentifier(SubjectPublicKeyInfo spki) {
      AuthorityKeyIdentifier var10000 = this;
      super();
      this.keyidentifier = null;
      this.certissuer = null;
      this.certserno = null;
      SHA1Digest var10001 = new SHA1Digest();
      byte[] var2 = new byte[var10001.getDigestSize()];
      byte[] var10003 = spki.getPublicKeyData().getBytes();
      var10001.update(var10003, 0, var10003.length);
      var10001.doFinal(var2, 0);
      var10000.keyidentifier = new DEROctetString(var2);
   }

   public AuthorityKeyIdentifier(SubjectPublicKeyInfo spki, GeneralNames name, BigInteger serialNumber) {
      AuthorityKeyIdentifier var10000 = this;
      AuthorityKeyIdentifier var10001 = this;
      AuthorityKeyIdentifier var10003 = this;
      super();
      this.keyidentifier = null;
      this.certissuer = null;
      this.certserno = null;
      SHA1Digest var10004 = new SHA1Digest();
      byte[] var4 = new byte[var10004.getDigestSize()];
      byte[] var10006 = spki.getPublicKeyData().getBytes();
      var10004.update(var10006, 0, var10006.length);
      var10004.doFinal(var4, 0);
      var10003.keyidentifier = new DEROctetString(var4);
      var10001.certissuer = GeneralNames.getInstance(name.toASN1Object());
      var10000.certserno = new DERInteger(serialNumber);
   }

   public AuthorityKeyIdentifier(GeneralNames name, BigInteger serialNumber) {
      this.keyidentifier = null;
      this.certissuer = null;
      this.certserno = null;
      this.keyidentifier = null;
      this.certissuer = GeneralNames.getInstance(name.toASN1Object());
      this.certserno = new DERInteger(serialNumber);
   }

   public AuthorityKeyIdentifier(byte[] keyIdentifier) {
      AuthorityKeyIdentifier var10000 = this;
      AuthorityKeyIdentifier var10001 = this;
      AuthorityKeyIdentifier var10002 = this;
      super();
      this.keyidentifier = null;
      this.certissuer = null;
      this.certserno = null;
      DEROctetString var2;
      var2 = new DEROctetString.<init>(keyIdentifier);
      var10002.keyidentifier = var2;
      var10001.certissuer = null;
      var10000.certserno = null;
   }

   public AuthorityKeyIdentifier(byte[] keyIdentifier, GeneralNames name, BigInteger serialNumber) {
      this.keyidentifier = null;
      this.certissuer = null;
      this.certserno = null;
      this.keyidentifier = new DEROctetString(keyIdentifier);
      this.certissuer = GeneralNames.getInstance(name.toASN1Object());
      this.certserno = new DERInteger(serialNumber);
   }

   public byte[] getKeyIdentifier() {
      ASN1OctetString var1;
      return (var1 = this.keyidentifier) != null ? var1.getOctets() : null;
   }

   public GeneralNames getAuthorityCertIssuer() {
      return this.certissuer;
   }

   public BigInteger getAuthorityCertSerialNumber() {
      DERInteger var1;
      return (var1 = this.certserno) != null ? var1.getValue() : null;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      ASN1OctetString var2;
      DERTaggedObject var3;
      if ((var2 = this.keyidentifier) != null) {
         var3 = new DERTaggedObject.<init>(false, 0, var2);
         var1.add(var3);
      }

      GeneralNames var5;
      if ((var5 = this.certissuer) != null) {
         var3 = new DERTaggedObject.<init>(false, 1, var5);
         var1.add(var3);
      }

      DERInteger var4;
      if ((var4 = this.certserno) != null) {
         DERTaggedObject var6;
         var6 = new DERTaggedObject.<init>(false, 2, var4);
         var1.add(var6);
      }

      return new DERSequence(var1);
   }

   public String toString() {
      return "AuthorityKeyIdentifier: KeyID(" + this.keyidentifier.getOctets() + ")";
   }
}
